==> TuxGuitar-0.8-src.tar.gz: TuxGuitar-0.8-src/src/org/herac/tuxguitar/gui/items/menu/MarkerMenuItem.java <==
/*
 * Created on 02-dic-2005
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package org.herac.tuxguitar.gui.items.menu;

import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Menu;
import org.eclipse.swt.widgets.MenuItem;
import org.eclipse.swt.widgets.Shell;
import org.herac.tuxguitar.gui.TablatureEditor;
import org.herac.tuxguitar.gui.TuxGuitar;
import org.herac.tuxguitar.gui.actions.marker.AddMarkerAction;
import org.herac.tuxguitar.gui.actions.marker.GoFirstMarkerAction;
import org.herac.tuxguitar.gui.actions.marker.GoLastMarkerAction;
import org.herac.tuxguitar.gui.actions.marker.GoNextMarkerAction;
import org.herac.tuxguitar.gui.actions.marker.GoPreviousMarkerAction;
import org.herac.tuxguitar.gui.actions.marker.ListMarkersAction;
import org.herac.tuxguitar.gui.items.ItemContainer;

/**
 * @author julian
 *
 * TODO To change the template for this generated type comment go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
public class MarkerMenuItem implements ItemContainer{
    private TablatureEditor tablatureEditor;
    private MenuItem markerMenuItem;
    private Menu menu;
    private MenuItem add;
    private MenuItem list;
    private MenuItem remove;    
    private MenuItem first;
    private MenuItem last;
    private MenuItem next;
    private MenuItem previous;    

    
    public MarkerMenuItem(Shell shell,Menu parent, int style,TablatureEditor tablatureEditor) {
        this.markerMenuItem = new MenuItem(parent, style);
        this.tablatureEditor = tablatureEditor;
        this.menu = new Menu(shell, SWT.DROP_DOWN);
    }

    
    public void showItems(){  
        //--ADD--
        this.add = new MenuItem(this.menu, SWT.PUSH);
        this.add.addSelectionListener(TuxGuitar.instance().getAction(AddMarkerAction.NAME));

        //--LIST--
        this.list = new MenuItem(this.menu, SWT.PUSH);
        this.list.addSelectionListener(TuxGuitar.instance().getAction(ListMarkersAction.NAME));        
        
        //--SEPARATOR--
        new MenuItem(this.menu, SWT.SEPARATOR);        
        
        //--FIRST--
        this.first = new MenuItem(this.menu, SWT.PUSH);
        this.first.addSelectionListener(TuxGuitar.instance().getAction(GoFirstMarkerAction.NAME));        

        //--PREVIOUS--
        this.previous = new MenuItem(this.menu, SWT.PUSH);
        this.previous.addSelectionListener(TuxGuitar.instance().getAction(GoPreviousMarkerAction.NAME));        
        
        //--PREVIOUS--
        this.next = new MenuItem(this.menu, SWT.PUSH);
        this.next.addSelectionListener(TuxGuitar.instance().getAction(GoNextMarkerAction.NAME));        
        
        //--LAST--
        this.last = new MenuItem(this.menu, SWT.PUSH);
        this.last.addSelectionListener(TuxGuitar.instance().getAction(GoLastMarkerAction.NAME));               
        
        this.markerMenuItem.setMenu(menu);      
        
        this.loadProperties();
    }

    
    public void update(){
    }
    
    public void loadProperties(){
        this.markerMenuItem.setText(TuxGuitar.getProperty("marker"));        
        this.add.setText(TuxGuitar.getProperty("marker.add"));
        this.list.setText(TuxGuitar.getProperty("marker.list"));
        this.first.setText(TuxGuitar.getProperty("marker.first"));
        this.last.setText(TuxGuitar.getProperty("marker.last"));
        this.previous.setText(TuxGuitar.getProperty("marker.previous"));
        this.next.setText(TuxGuitar.getProperty("marker.next"));
    }        
}

==> TuxGuitar-0.9-src.tar.gz: TuxGuitar-0.9-src/src/org/herac/tuxguitar/gui/items/menu/MarkerMenuItem.java <==
/*
 * Created on 02-dic-2005
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package org.herac.tuxguitar.gui.items.menu;

import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Menu;
import org.eclipse.swt.widgets.MenuItem;
import org.eclipse.swt.widgets.Shell;
import org.herac.tuxguitar.gui.SystemImages;
import org.herac.tuxguitar.gui.TuxGuitar;
import org.herac.tuxguitar.gui.actions.marker.AddMarkerAction;
import org.herac.tuxguitar.gui.actions.marker.GoFirstMarkerAction;
import org.herac.tuxguitar.gui.actions.marker.GoLastMarkerAction;
import org.herac.tuxguitar.gui.actions.marker.GoNextMarkerAction;
import org.herac.tuxguitar.gui.actions.marker.GoPreviousMarkerAction;
import org.herac.tuxguitar.gui.actions.marker.ListMarkersAction;
import org.herac.tuxguitar.gui.editors.TablatureEditor;
import org.herac.tuxguitar.gui.items.MenuItems;

/**
 * @author julian
 *
 * TODO To change the template for this generated type comment go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
public class MarkerMenuItem implements MenuItems{
    private TablatureEditor tablatureEditor;
    private MenuItem markerMenuItem;
    private Menu menu;
    private MenuItem add;
    private MenuItem list;
    private MenuItem remove;    
    private MenuItem first;
    private MenuItem last;
    private MenuItem next;
    private MenuItem previous;    
    
    public MarkerMenuItem(Shell shell,Menu parent, int style,TablatureEditor tablatureEditor) {
        this.markerMenuItem = new MenuItem(parent, style);
        this.tablatureEditor = tablatureEditor;
        this.menu = new Menu(shell, SWT.DROP_DOWN);
    }
    
    public void showItems(){  
        //--ADD--
        this.add = new MenuItem(this.menu, SWT.PUSH);
        this.add.setImage(SystemImages.MARKER_ADD);
        this.add.addSelectionListener(TuxGuitar.instance().getAction(AddMarkerAction.NAME));

        //--LIST--
        this.list = new MenuItem(this.menu, SWT.PUSH);
        this.list.setImage(SystemImages.MARKER_LIST);
        this.list.addSelectionListener(TuxGuitar.instance().getAction(ListMarkersAction.NAME));        
        
        //--SEPARATOR--
        new MenuItem(this.menu, SWT.SEPARATOR);        
        
        //--FIRST--
        this.first = new MenuItem(this.menu, SWT.PUSH);
        this.first.setImage(SystemImages.MARKER_FIRST);
        this.first.addSelectionListener(TuxGuitar.instance().getAction(GoFirstMarkerAction.NAME));        

        //--PREVIOUS--
        this.previous = new MenuItem(this.menu, SWT.PUSH);
        this.previous.setImage(SystemImages.MARKER_PREVIOUS);
        this.previous.addSelectionListener(TuxGuitar.instance().getAction(GoPreviousMarkerAction.NAME));        
        
        //--PREVIOUS--
        this.next = new MenuItem(this.menu, SWT.PUSH);
        this.next.setImage(SystemImages.MARKER_NEXT);
        this.next.addSelectionListener(TuxGuitar.instance().getAction(GoNextMarkerAction.NAME));        
        
        //--LAST--
        this.last = new MenuItem(this.menu, SWT.PUSH);
        this.last.setImage(SystemImages.MARKER_LAST);
        this.last.addSelectionListener(TuxGuitar.instance().getAction(GoLastMarkerAction.NAME));               
        
        this.markerMenuItem.setMenu(menu);      
        
        this.loadProperties();
    }

    
    public void update(){
    }
    
    public void loadProperties(){
        this.markerMenuItem.setText(TuxGuitar.getProperty("marker"));        
        this.add.setText(TuxGuitar.getProperty("marker.add"));
        this.list.setText(TuxGuitar.getProperty("marker.list"));
        this.first.setText(TuxGuitar.getProperty("marker.first"));
        this.last.setText(TuxGuitar.getProperty("marker.last"));
        this.previous.setText(TuxGuitar.getProperty("marker.previous"));
        this.next.setText(TuxGuitar.getProperty("marker.next"));
    }        
}
